@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.42';
+  $CPAN::Perl::Releases::VERSION = '0.60';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -244,6 +244,37 @@ our $data =
     "tar.bz2" => "B/BI/BINGOS/perl-5.15.7.tar.bz2",
     "tar.gz" => "B/BI/BINGOS/perl-5.15.7.tar.gz",
   },
+  "5.15.8" => {
+    "tar.bz2" => "C/CO/CORION/perl-5.15.8.tar.bz2",
+    "tar.gz" => "C/CO/CORION/perl-5.15.8.tar.gz",
+  },
+  "5.15.9" => {
+    "tar.bz2" => "A/AB/ABIGAIL/perl-5.15.9.tar.bz2",
+    "tar.gz" => "A/AB/ABIGAIL/perl-5.15.9.tar.gz",
+  },
+  "5.16.0-RC0" => {
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.0-RC0.tar.gz",
+  },
+  "5.16.0-RC1" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.0-RC1.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.0-RC1.tar.gz",
+  },
+  "5.16.0-RC2" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.0-RC2.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.0-RC2.tar.gz",
+  },
+  "5.16.0" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.0.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.0.tar.gz",
+  },
+  "5.17.0" => {
+    "tar.bz2" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.bz2",
+    "tar.gz" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.gz",
+  },
+  "5.17.1" => {
+    "tar.bz2" => "D/DO/DOY/perl-5.17.1.tar.bz2",
+    "tar.gz" => "D/DO/DOY/perl-5.17.1.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -352,7 +383,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.42
+version 0.60
 
 =head1 SYNOPSIS
 
